"use strict";

var _interopRequireDefault = require("babel-runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = buildOptions;

require("babel-polyfill/lib/core-js/modules/es7.array.includes");

var _assign = _interopRequireDefault(require("babel-runtime/core-js/object/assign"));

var _defaultOptions = _interopRequireDefault(require("./defaultOptions"));

var _util = require("./util");

/* eslint prefer-const: 0*/

/**
 * Build a valid options object that can be used to pass
 * options to other presets and/or plugins.
 *
 * @param {object} _config
 * @returns {{async:object, config:object, env:object, resolver:object}}
 */
function buildOptions(_config) {
  if (_config === void 0) {
    _config = {};
  }

  var config = (0, _assign.default)({}, _defaultOptions.default, _config);
  var asyncOptions, envOptions, resolverOptions, runtimeOptions;
  if (typeof config.stage !== "number") config.stage = -1;
  envOptions = {
    "debug": !!config.debug,
    "include": (0, _util.castArray)(config.include),
    "exclude": (0, _util.castArray)(config.exclude),
    "loose": !!config.loose,
    "modules": config.modules,
    "spec": !!config.spec,
    "targets": {},
    "useBuiltIns": config.useBuiltIns,
    "forceAllTransforms": !!config.forceAllTransforms
  };

  if (!config.disableResolver) {
    resolverOptions = {
      "alias": config.alias || _defaultOptions.default.alias,
      "cwd": config.cwd || _defaultOptions.default.cwd,
      "extensions": (0, _util.castArray)(config.extensions, _defaultOptions.default.extensions),
      "stripExtensions": (0, _util.castArray)(config.stripExtensions, _defaultOptions.default.stripExtensions),
      "root": (0, _util.castArray)(config.root, _defaultOptions.default.root),
      "transformFunctions": config.transformFunctions || config.importers,
      "resolvePath": config.resolvePath || config.resolver
    };
  }

  if (!config.regenerator) (0, _util.listOnce)(envOptions.exclude, "transform-regenerator");

  if (!config.asyncToGenerator) {
    (0, _util.listOnce)(envOptions.exclude, "transform-async-to-generator");
    var index = envOptions.exclude.indexOf("transform-async-to-module-method");
    if (index === -1) asyncOptions = {
      "module": config.asyncModule || _defaultOptions.default.asyncModule,
      "method": config.asyncMethod || _defaultOptions.default.asyncMethod
    };else if (index !== -1) envOptions.exclude.splice(index, 1);
  }

  if (typeof config.runtime === "object" || typeof config.runtime === "string" || config.runtime === true) {
    runtimeOptions = {
      "helpers": true,
      "polyfill": true,
      "regenerator": true,
      "moduleName": typeof config.runtime === "string" ? config.runtime : "babel-runtime",
      "useBuiltIns": false,
      "useESModules": false
    };
    if (typeof config.runtime === "object") (0, _assign.default)(runtimeOptions, config.runtime);
  }

  if (!config.node && config.node !== false) {
    var engines = (0, _util.getPackage)(config.cwd || _defaultOptions.default.cwd).engines;
    config.node = engines && engines.node ? (0, _util.majorSemver)(String(engines.node)) : "current";
  }

  if (typeof config.node === "string" && config.node !== "current") {
    config.node = config.node.includes(".") ? parseFloat(config.node) : parseInt(config.node, 10);
  }

  _util.targets.forEach(function (target) {
    if (!config.hasOwnProperty(target)) return 0;

    if (config[target] !== false) {
      envOptions.targets[target] = config[target];
    }
  });

  return {
    async: asyncOptions,
    config,
    env: envOptions,
    resolver: resolverOptions,
    runtime: runtimeOptions
  };
}